import abc
from typing import Optional

import requests

from openweather_api.settings import API_BASE_URL
from openweather_api.utils import build_full_url


class ClientCore(abc.ABC):

    def __init__(self, api_key: str, base_url: Optional[str] = API_BASE_URL) -> None:
        self.base_url = base_url
        self.api_key = api_key

    def build_params(self, params: Optional[dict] = None):
        params = params if params else {}
        params['appid'] = self.api_key
        return params

    def get(self, endpoint: str, params: Optional[dict] = None) -> requests.Response:
        url = build_full_url(self.base_url, endpoint)
        params = self.build_params(params)
        return requests.get(url, params=params)



import pytest

from openweather_api.utils import build_full_url


@pytest.mark.parametrize('base_url, endpoint, expected_full_url', [
    ('https://test.com/1/', '2/3', 'https://test.com/1/2/3'),
    ('https://test.com/1/', '/2/3', 'https://test.com/1/2/3'),
    ('https://test.com/1', '/2/3', 'https://test.com/1/2/3'),
    ('https://test.com/1', '2/3', 'https://test.com/1/2/3')
])
def test_build_full_url(base_url, endpoint, expected_full_url):
    assert build_full_url(base_url, endpoint) == expected_full_url



import functools
import gzip
import json
from io import BytesIO
from typing import List
from urllib.parse import urljoin

import requests

from openweather_api.settings import CITY_ID_LIST_URL


def build_full_url(base_url: str, endpoint: str) -> str:
    if not base_url.endswith('/'):
        base_url += '/'
    if endpoint.startswith('/'):
        endpoint = endpoint[1:]

    return urljoin(base_url, endpoint)


@functools.lru_cache()
def load_cities() -> List:
    response = requests.get(CITY_ID_LIST_URL)
    with gzip.open(BytesIO(response.content), 'rb') as f:
        cities = json.loads(f.read())
    return cities



import requests

from openweather_api.core import ClientCore


class APIClient(ClientCore):

    endpoints = {
        'current_weather_data': 'weather'
    }

    def get_current_weather_by_city_name(self, city: str) -> requests.Response:
        endpoint = self.endpoints['current_weather_data']
        params = {
            'q': city
        }
        return self.get(endpoint=endpoint, params=params)

    def get_current_weather_by_city_id(self, city_id: str) -> str:
        pass


#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['openweather_api']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.24.0', 'iso3166>=1.0.1']

extras_require = \
{'test': ['pytest', 'pytest-cov', 'pytest-sugar']}

setup(name='openweather_api',
      version='0.1.0',
      description='OpenWeather API client',
      author='Alessandro De Noia',
      author_email='alessandro.denoia@gmail.com',
      url='https://github.com/sdonk/openweather-api-client',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.6',
     )
